@@ -92,7 +92,7 @@ impl PyRange<'_> {
 }
 
 #[derive(Clone)]
-pub struct PySplitDelimiterBehavior(SplitDelimiterBehavior);
+pub struct PySplitDelimiterBehavior(pub SplitDelimiterBehavior);
 
 impl FromPyObject<'_> for PySplitDelimiterBehavior {
     fn extract(obj: &PyAny) -> PyResult<Self> {
@@ -553,27 +553,27 @@ impl PyNormalizedStringRefMut {
 
     fn slice(&self, range: PyRange) -> PyResult<Option<PyNormalizedString>> {
         self.inner
-            .map(|n| slice(&n, &range))
+            .map(|n| slice(n, &range))
             .ok_or_else(PyNormalizedStringRefMut::destroyed_error)?
     }
 
     fn filter(&mut self, func: &PyAny) -> PyResult<()> {
         self.inner
-            .map_mut(|mut n| filter(&mut n, func))
+            .map_mut(|n| filter(n, func))
             .ok_or_else(PyNormalizedStringRefMut::destroyed_error)??;
         Ok(())
     }
 
     fn for_each(&self, func: &PyAny) -> PyResult<()> {
         self.inner
-            .map(|n| for_each(&n, func))
+            .map(|n| for_each(n, func))
             .ok_or_else(PyNormalizedStringRefMut::destroyed_error)??;
         Ok(())
     }
 
     fn map(&mut self, func: &PyAny) -> PyResult<()> {
         self.inner
-            .map_mut(|mut n| map(&mut n, func))
+            .map_mut(|n| map(n, func))
             .ok_or_else(PyNormalizedStringRefMut::destroyed_error)??;
         Ok(())
     }
